# k8s-voca

### kubernetes vocabulary

![LGTM](https://i.lgtm.fun/2i0x.png)

- [https://pypi.org/project/k8s-voca](https://pypi.org/project/k8s-voca)

```
.　/＼＿／ヽ
／ _ノ　ヽ_ ＼
|　　━　 ━　i
＼ミ (_人_) 彡
　／￣￣⌒＼/⌒)―――― - kubernetes vocabulary
. /　　　　＿／　
. |　　　＼
　＼ 〇_　 ＼
　　＼ノ.＼_ノ
```

# User Guide

- [https://dmario24.github.io/k8s-voca](https://dmario24.github.io/k8s-voca)

```
$ pip install k8s-voca
$ kv node
>> 쿠버네티스는 컨테이너를 파드내에 배치하고 노드 에서 실행함으로 워크로드를 구동한다. 노드는 클러스터에 따라 가상(EC2) 또는 물리적 머신일 수 있다.
```

# Template creation help

- cookiecutter https://github.com/becky2sawyer/cookiecutter-pypackage-mkdocss.git
